@@ -4,40 +4,50 @@ mapdeckArcDependency <- function() {
 			name = "arc",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/arc", package = "mapdeck"),
-			script = c("arc.js")
+			script = c("arc.js"),
+			all_files = FALSE
 		)
 	)
 }
 
-
 #' Add arc
 #'
 #' The Arc Layer renders raised arcs joining pairs of source and target coordinates
 #'
 #' @param map a mapdeck map object
-#' @param data data to be used in the layer. All coordinates are expected to be in
-#' Web Mercator Projection
+#' @param data data to be used in the layer. All coordinates are expected to be
+#' EPSG:4326 (WGS 84) coordinate system
 #' @param layer_id single value specifying an id for the layer. Use this value to
 #' distinguish between shape layers of the same type. Layers with the same id are likely
 #' to conflict and not plot correctly
-#' @param origin vector of longitude and latitude columns, or an \code{sfc} column
-#' @param destination vector of longitude and latitude columns, or an \code{sfc} column
+#' @param origin vector of longitude and latitude columns, and optionally an elevation column,
+#' or an \code{sfc} column
+#' @param destination vector of longitude and latitude columns, and optionally an elevatino column,
+#' or an \code{sfc} column
 #' @param id an id value in \code{data} to identify layers when interacting in Shiny apps.
-#' @param stroke_from variable or hex colour to use as the staring stroke colour
+#' @param stroke_from column of \code{data} or hex colour to use as the staring stroke colour.
+#' If using a hex colour, use either a single value, or a vector the same length as \code{data}
 #' @param stroke_from_opacity Either a string specifying the
 #' column of \code{data} containing the stroke opacity of each shape, or a value
-#' between 1 and 255 to be applied to all the shapes
-#' @param stroke_to variable or hex colour to use as the ending stroke colour
+#' between 1 and 255 to be applied to all the shapes. If a hex-string is used as the
+#' colour, this argument is ignored and you should include the alpha on the hex string
+#' @param stroke_to column of \code{data} or hex colour to use as the ending stroke colour.
+#' If using a hex colour, use either a single value, or a vector the same length as \code{data}
 #' @param stroke_to_opacity Either a string specifying the
 #' column of \code{data} containing the stroke opacity of each shape, or a value
-#' between 1 and 255 to be applied to all the shapes
-#' @param stroke_width width of the stroke
+#' between 1 and 255 to be applied to all the shapes. If a hex-string is used as the
+#' colour, this argument is ignored and you should include the alpha on the hex string
+#' @param stroke_width width of the stroke in pixels
+#' @param height value to multiply the height.
+#' @param tilt value to tilt the arcs to the side, in degrees [-90, 90]
 #' @param tooltip variable of \code{data} containing text or HTML to render as a tooltip
 #' @param auto_highlight logical indicating if the shape under the mouse should auto-highlight
 #' @param highlight_colour hex string colour to use for highlighting. Must contain the alpha component.
 #' @param palette string or matrix. String will be one of \code{colourvalues::colour_palettes()}.
-#' A matrix is a 3 or 4 column numeric matrix of values between [0, 255],
-#' where the 4th column represents the alpha.
+#' A matrix must have at least 5 rows, and 3 or 4 columns of values between [0, 255],
+#' where the 4th column represents the alpha. You can use a named list to specify a different
+#' palette for different colour options (where available),
+#'  e.g. list(fill_colour = "viridis", stroke_colour = "inferno")
 #' @param na_colour hex string colour to use for NA values
 #' @param legend either a logical indiciating if the legend(s) should be displayed, or
 #' a named list indicating which colour attributes should be included in the legend.
@@ -46,6 +56,10 @@ mapdeckArcDependency <- function() {
 #' @param update_view logical indicating if the map should update the bounds to include this layer
 #' @param focus_layer logical indicating if the map should update the bounds to only include this layer
 #' @param transitions list specifying the duration of transitions.
+#' @param brush_radius radius of the brush in metres. Default NULL. If supplied,
+#' the arcs will only show if the origin or destination are within the radius of the mouse.
+#' If NULL, all arcs are displayed
+#' @param digits number of digits for rounding coordinates
 #'
 #' @section data:
 #'
@@ -69,6 +83,7 @@ mapdeckArcDependency <- function() {
 #' \itemize{
 #'   \item{css - a string of valid \code{css} for controlling the appearance of the legend}
 #'   \item{title - a string to use for the title of the legend}
+#'   \item{digits - number to round the legend values to}
 #' }
 #'
 #' If the layer allows different fill and stroke colours, you can use different options for each. See examples in \link{add_arc}.
@@ -108,6 +123,7 @@ mapdeckArcDependency <- function() {
 #'
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
 #' url <- 'https://raw.githubusercontent.com/plotly/datasets/master/2011_february_aa_flight_paths.csv'
 #' flights <- read.csv(url)
@@ -115,7 +131,7 @@ mapdeckArcDependency <- function() {
 #' flights$stroke <- sample(1:3, size = nrow(flights), replace = T)
 #' flights$info <- paste0("<b>",flights$airport1, " - ", flights$airport2, "</b>")
 #'
-#' mapdeck( token = key, style = mapdeck_style("dark"), pitch = 45 ) %>%
+#' mapdeck( style = mapdeck_style("dark"), pitch = 45 ) %>%
 #'   add_arc(
 #'   data = flights
 #'   , layer_id = "arc_layer"
@@ -132,26 +148,78 @@ mapdeckArcDependency <- function() {
 #'     css = "max-height: 100px;")
 #'  )
 #'
-#' ## Using a 2-sfc-column sf object
-#' library(sf)
+#' mapdeck( style = mapdeck_style("dark")) %>%
+#'   add_arc(
+#'   data = flights
+#'   , layer_id = "arc_layer"
+#'   , origin = c("start_lon", "start_lat")
+#'   , destination = c("end_lon", "end_lat")
+#'   , stroke_from = "airport1"
+#'   , stroke_to = "airport2"
+#'   , stroke_width = "stroke"
+#'   )
 #'
-#' sf_flights <- cbind(
-#'   sf::st_as_sf(flights, coords = c("start_lon", "start_lat"))
-#'   , sf::st_as_sf(flights[, c("end_lon","end_lat")], coords = c("end_lon", "end_lat"))
-#' )
+#' ## Arcs can have an elevated start & destination
+#' flights$start_elev <- sample(100000:1000000, size = nrow(flights), replace = TRUE )
+#'
+#' mapdeck( style = mapdeck_style("dark")) %>%
+#'   add_arc(
+#'   data = flights
+#'   , layer_id = "arc_layer"
+#'   , origin = c("start_lon", "start_lat", "start_elev")
+#'   , destination = c("end_lon", "end_lat", "start_elev")
+#'   , stroke_from = "airport1"
+#'   , stroke_to = "airport2"
+#'   , stroke_width = "stroke"
+#'   )
+#'
+#' ## Using a 2-sfc-column sf object
+#' library(sfheaders)
+#'
+#' sf_flights <- sfheaders::sf_point(
+#'   flights
+#'   , x = "start_lon"
+#'   , y = "start_lat"
+#'   , z = "start_elev"
+#'   , keep = TRUE
+#'   )
+#' destination <- sfheaders::sfc_point(
+#'   flights
+#'   , x = "end_lon"
+#'   , y = "end_lat"
+#'   , z = "start_elev"
+#'   )
+#'
+#' sf_flights$destination <- destination
 #'
 #' mapdeck(
-#'   token = key
 #' ) %>%
 #'  add_arc(
 #'    data = sf_flights
 #'    , origin = 'geometry'
-#'    , destination = 'geometry.1'
+#'    , destination = 'destination'
 #'    , layer_id = 'arcs'
 #'    , stroke_from = "airport1"
 #'    , stroke_to = "airport2"
 #' )
 #'
+#' ## using a brush
+#'
+#' mapdeck(
+#'   , style = mapdeck_style("light")
+#' ) %>%
+#'  add_arc(
+#'    data = sf_flights
+#'    , origin = 'geometry'
+#'    , destination = 'destination'
+#'    , layer_id = 'arcs'
+#'    , stroke_from = "airport1"
+#'    , stroke_to = "airport2"
+#'    , stroke_width = 4
+#'    , brush_radius = 500000
+#' )
+#'
+#'
 #'
 #' }
 #'
@@ -178,6 +246,8 @@ add_arc <- function(
 	stroke_to = NULL,
 	stroke_to_opacity = NULL,
 	stroke_width = NULL,
+	tilt = NULL,
+	height = NULL,
 	tooltip = NULL,
 	auto_highlight = FALSE,
 	highlight_colour = "#AAFFFFFF",
@@ -188,7 +258,9 @@ add_arc <- function(
 	na_colour = "#808080FF",
 	update_view = TRUE,
 	focus_layer = FALSE,
-	transitions = NULL
+	transitions = NULL,
+	digits = 6,
+	brush_radius = NULL
 ) {
 
 	l <- list()
@@ -199,6 +271,8 @@ add_arc <- function(
 	l[["stroke_from_opacity"]] <- force(stroke_from_opacity)
 	l[["stroke_to_opacity"]] <- force(stroke_to_opacity)
 	l[["stroke_width"]] <- force(stroke_width)
+	l[["tilt"]] <- force(tilt)
+	l[["height"]] <- force(height)
 	l[["tooltip"]] <- force(tooltip)
 	l[["id"]] <- force(id)
 	l[["na_colour"]] <- force(na_colour)
@@ -227,28 +301,42 @@ add_arc <- function(
 
 	tp <- l[["data_type"]]
 	l[["data_type"]] <- NULL
-	jsfunc <- "add_arc_geo"
 
-	map <- addDependency(map, mapdeckArcDependency())
+	# if(!is.null(brush_radius)) {
+	# 	jsfunc <- "add_arc_brush_geo"
+	# 	map <- addDependency(map, mapdeckArcBrushDependency())
+	# } else {
+		jsfunc <- "add_arc_geo"
+		map <- addDependency(map, mapdeckArcDependency())
+	# }
 
   if ( tp == "sf" ) {
 		geometry_column <- c( "origin", "destination" )
-		shape <- rcpp_arc_geojson( data, l, geometry_column )
+		shape <- rcpp_od_geojson( data, l, geometry_column, digits, "arc" )
   } else if ( tp == "df" ) {
-  	geometry_column <- list( origin = c("start_lon", "start_lat"), destination = c("end_lon", "end_lat") )
-  	shape <- rcpp_arc_geojson_df( data, l, geometry_column )
+  	geometry_column <- list( origin = c("start_lon", "start_lat", "start_elev"), destination = c("end_lon", "end_lat", "end_elev") )
+  	shape <- rcpp_od_geojson_df( data, l, geometry_column, digits, "arc" )
   } else if ( tp == "sfencoded" ) {
   	geometry_column <- c("origin", "destination")
-  	shape <- rcpp_arc_polyline( data, l, geometry_column )
-  	jsfunc <- "add_arc_polyline"
+  	shape <- rcpp_od_polyline( data, l, geometry_column, "arc" )
+  	# if(!is.null(brush_radius)) {
+  	# 	jsfunc <- "add_arc_brush_polyline"
+  	# } else {
+  	#   jsfunc <- "add_arc_polyline"
+  	# }
   }
 
 	js_transition <- resolve_transitions( transitions, "arc" )
-	shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	if( inherits( legend, "json" ) ) {
+		shape[["legend"]] <- legend
+	} else {
+		shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], layer_id, auto_highlight,
-		highlight_colour, shape[["legend"]], bbox, update_view, focus_layer, js_transition
+		map, jsfunc, map_type( map ), shape[["data"]], layer_id, auto_highlight,
+		highlight_colour, shape[["legend"]], bbox, update_view, focus_layer, js_transition,
+		brush_radius
 		)
 }
 
@@ -263,5 +351,5 @@ add_arc <- function(
 #' @export
 clear_arc <- function( map, layer_id = NULL ) {
 	layer_id <- layerId(layer_id, "arc")
-	invoke_method(map, "md_layer_clear", layer_id, "arc" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "arc" )
 }
