@@ -4,7 +4,8 @@ mapdeckPointcloudDependency <- function() {
 			name = "pointcloud",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/pointcloud", package = "mapdeck"),
-			script = c("pointcloud.js")
+			script = c("pointcloud.js"),
+			all_files = FALSE
 		)
 	)
 }
@@ -16,8 +17,8 @@ mapdeckPointcloudDependency <- function() {
 #' with a certain radius.
 #'
 #' @inheritParams add_scatterplot
-#' @param elevation column containing the elevation values
-#' @param radius value in pixels of each point
+#' @param elevation column containing the elevation values. Default 0
+#' @param radius value in pixels of each point. Default 10.
 #' @param light_settings list of light setting parameters. See \link{light_settings}
 #'
 #' @inheritSection add_polygon data
@@ -43,11 +44,12 @@ mapdeckPointcloudDependency <- function() {
 #' \donttest{
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
 #' df <- capitals
 #' df$z <- sample(10000:10000000, size = nrow(df))
 #'
-#' mapdeck(token = key, style = mapdeck_style("dark")) %>%
+#' mapdeck(style = mapdeck_style("dark")) %>%
 #' add_pointcloud(
 #'   data = df
 #'   , lon = 'lon'
@@ -56,14 +58,13 @@ mapdeckPointcloudDependency <- function() {
 #'   , layer_id = 'point'
 #'   , fill_colour = "country"
 #'   , tooltip = "country"
-#'   , update_view = FALSE
 #' )
 #'
 #' ## as an sf object wtih a Z attribute
-#' library(sf)
-#' sf <- sf::st_as_sf( df , coords = c("lon","lat","z"))
+#' library(sfheaders)
+#' sf <- sfheaders::sf_point( df, x = "lon", y = "lat", z = "z" )
 #'
-#' mapdeck(token = key, style = mapdeck_style("dark")) %>%
+#' mapdeck(style = mapdeck_style("dark")) %>%
 #' add_pointcloud(
 #'   data = sf
 #'   , layer_id = 'point'
@@ -102,16 +103,23 @@ add_pointcloud <- function(
 	legend_format = NULL,
 	update_view = TRUE,
 	focus_layer = FALSE,
-	transitions = NULL
+	digits = 6,
+	transitions = NULL,
+	brush_radius = NULL
 ) {
 
+	## using binary data requires hex-colorus to include teh alpha
+	if( !is.null( fill_colour ) ) {
+	  fill_colour <- appendAlpha( fill_colour )
+	}
+
 	l <- list()
 	l[["lon"]] <- force( lon )
 	l[["lat"]] <- force( lat )
 	l[["polyline"]] <- force( polyline )
 	l[["elevation"]] <- force( elevation )
-	l[["fill_colour"]] <- force( fill_colour)
-	l[["fill_opacity"]] <- force( fill_opacity )
+	l[["fill_colour"]] <- force( fill_colour )
+	l[["fill_opacity"]] <- resolve_opacity( fill_opacity )
 	l[["tooltip"]] <- force( tooltip )
 	l[["id"]] <- force( id )
 	l[["na_colour"]] <- force( na_colour )
@@ -119,7 +127,7 @@ add_pointcloud <- function(
 	l <- resolve_palette( l, palette )
 	l <- resolve_legend( l, legend )
 	l <- resolve_legend_options( l, legend_options )
-	l <- resolve_elevation_data( data, l, elevation, c("POINT","MULTIPOINT") )
+	l <- resolve_elevation_data( data, l, elevation, c("POINT") )
 
 	bbox <- init_bbox()
 	update_view <- force( update_view )
@@ -143,36 +151,51 @@ add_pointcloud <- function(
 
 	tp <- l[["data_type"]]
 	l[["data_type"]] <- NULL
-	jsfunc <- "add_pointcloud_geo"
+	jsfunc <- "add_pointcloud_geo_columnar"
 
 	if ( tp == "sf" ) {
-		geometry_column <- c( "geometry" )
-		shape <- rcpp_pointcloud_geojson( data, l, geometry_column )
+
+		geometry_column <- list( geometry = c("lon","lat","elevation") )  ## using columnar structure, the 'sf' is converted to a data.frame
+		## so the geometry columns are obtained after sfheaders::sf_to_df()
+		l[["geometry"]] <- NULL
+		shape <- rcpp_point_sf_columnar( data, l, geometry_column, digits, "pointcloud" )
+
+		# geometry_column <- c( "geometry" )
+		# shape <- rcpp_point_geojson( data, l, geometry_column, digits, "pointcloud" )
 
 	} else if ( tp == "df" ) {
 		## TODO( here or in rcpp? )
-		if( is.null(elevation) ){
+		if( is.null( elevation ) ){
 			l[["elevation"]] <- 0
 		}
 
-		geometry_column <- list( geometry = c("lon","lat","elevation") )
-	  shape <- rcpp_pointcloud_geojson_df( data, l, geometry_column )
+		#print( head( data )  )
+		geometry_column <- list( geometry = c("lon", "lat","elevation") )
+		shape <- rcpp_point_df_columnar( data, l, geometry_column, digits, "pointcloud" )
+
+	# 	geometry_column <- list( geometry = c("lon","lat","elevation") )
+	#   shape <- rcpp_point_geojson_df( data, l, geometry_column, digits, "pointcloud" )
 
 	} else if ( tp == "sfencoded" ) {
 
 		geometry_column <- "polyline"
-		shape <- rcpp_pointcloud_polyline( data, l, geometry_column )
+		shape <- rcpp_point_polyline( data, l, geometry_column, "pointcloud" )
 		jsfunc <- "add_pointcloud_polyline"
 	}
 
 	light_settings <- jsonify::to_json(light_settings, unbox = T)
 	js_transitions <- resolve_transitions( transitions, "pointcloud" )
-	shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+
+	if( inherits( legend, "json" ) ) {
+		shape[["legend"]] <- legend
+	} else {
+		shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], radius, layer_id, light_settings,
+		map, jsfunc, map_type( map ), shape[["data"]], nrow(data), radius, layer_id, light_settings,
 		auto_highlight, highlight_colour, shape[["legend"]], bbox, update_view, focus_layer,
-		js_transitions
+		js_transitions, brush_radius
 		)
 }
 
@@ -181,6 +204,6 @@ add_pointcloud <- function(
 #' @export
 clear_pointcloud <- function( map, layer_id = NULL) {
 	layer_id <- layerId( layer_id, "pointcloud" )
-	invoke_method(map, "md_layer_clear", layer_id, "pointcloud" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "pointcloud" )
 }
 
