@@ -4,7 +4,8 @@ mapdeckScreengridDependency <- function() {
 			name = "screengrid",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/screengrid", package = "mapdeck"),
-			script = c("screengrid.js")
+			script = c("screengrid.js"),
+			all_files = FALSE
 		)
 	)
 }
@@ -18,10 +19,12 @@ mapdeckScreengridDependency <- function() {
 #' @inheritParams add_polygon
 #' @param lon column containing longitude values
 #' @param lat column containing latitude values
-#' @param weight the weight of each value
+#' @param weight the weight of each value. Default 1
+#' @param aggregation one of 'min', 'mean', 'max', 'sum'.
+#' If supplied it specifies how the weights used.
 #' @param colour_range vector of 6 hex colours
-#' @param opacity opacity of cells. Value between 0 and 1
-#' @param cell_size size of grid squares in pixels
+#' @param opacity opacity of cells. Value between 0 and 1. Default 0.8
+#' @param cell_size size of grid squares in pixels. Default 50
 #'
 #' @inheritSection add_polygon data
 #'
@@ -30,6 +33,7 @@ mapdeckScreengridDependency <- function() {
 #'
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
 #' df <- read.csv(paste0(
 #' 'https://raw.githubusercontent.com/uber-common/deck.gl-data/master/',
@@ -39,7 +43,7 @@ mapdeckScreengridDependency <- function() {
 #' df <- df[ !is.na(df$lng), ]
 #' df$weight <- sample(1:10, size = nrow(df), replace = T)
 #'
-#' mapdeck( token = key, style = mapdeck_style('dark'), pitch = 45 ) %>%
+#' mapdeck( style = mapdeck_style('dark'), pitch = 45 ) %>%
 #' add_screengrid(
 #'   data = df
 #'   , lat = "lat"
@@ -51,9 +55,10 @@ mapdeckScreengridDependency <- function() {
 #' )
 #'
 #' ## as an sf object
-#' library(sf)
-#' sf <- sf::st_as_sf( df, coords = c("lng", "lat"))
-#' mapdeck( token = key, style = mapdeck_style('dark'), pitch = 45 ) %>%
+#' library(sfheaders)
+#' sf <- sfheaders::sf_point( df, x = "lng", y = "lat")
+#'
+#' mapdeck( style = mapdeck_style('dark'), pitch = 45 ) %>%
 #' add_screengrid(
 #'   data = sf
 #'   , weight = "weight",
@@ -76,20 +81,26 @@ add_screengrid <- function(
 	lat = NULL,
 	polyline = NULL,
 	weight = NULL,
+	aggregation = c("sum","mean","min","max"),
 	colour_range = NULL,
 	opacity = 0.8,
 	cell_size = 50,
 	layer_id = NULL,
 	update_view = TRUE,
-	focus_layer = FALSE
+	focus_layer = FALSE,
+	digits = 6
 ) {
+	brush_radius = NULL
 	l <- list()
 	l[["polyline"]] <- force( polyline )
 	l[["weight"]] <- force( weight )
 	l[["lon"]] <- force( lon )
 	l[["lat"]] <- force( lat )
 
-	l <- resolve_data( data, l, c("POINT","MULTIPOINT") )
+	l <- resolve_data( data, l, c("POINT") )
+
+	aggregation <- match.arg( aggregation )
+	aggregation <- toupper( aggregation )
 
 	bbox <- init_bbox()
 	update_view <- force( update_view )
@@ -116,7 +127,7 @@ add_screengrid <- function(
 	}
 
 	if(length(colour_range) != 6)
-		stop("colour_range must have 6 hex colours")
+		stop("mapdeck - colour_range must have 6 hex colours")
 	## end parameter checks
 
 	checkHex(colour_range)
@@ -129,19 +140,19 @@ add_screengrid <- function(
 	jsfunc <- "add_screengrid_geo"
 	if( tp == "sf" ) {
 		geometry_column <- c( "geometry" )
-		shape <- rcpp_screengrid_geojson( data, l, geometry_column )
+		shape <- rcpp_aggregate_geojson( data, l, geometry_column, digits, "screengrid" )
 	} else if ( tp == "df" ) {
 		geometry_column <- list( geometry = c("lon", "lat") )
-		shape <- rcpp_screengrid_geojson_df( data, l, geometry_column )
+		shape <- rcpp_aggregate_geojson_df( data, l, geometry_column, digits, "screengrid" )
 	} else if ( tp == "sfencoded" ) {
 		geometry_column <- "polyline"
-		shape <- rcpp_screengrid_polyline( data, l, geometry_column )
+		shape <- rcpp_aggregate_polyline( data, l, geometry_column, "screengrid" )
 		jsfunc <- "add_screengrid_polyline"
 	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], layer_id, opacity, cell_size, colour_range,
-		bbox, update_view, focus_layer
+		map, jsfunc, map_type( map ), shape[["data"]], layer_id, opacity, cell_size, colour_range,
+		bbox, update_view, focus_layer, aggregation, brush_radius
 		)
 }
 
@@ -150,6 +161,6 @@ add_screengrid <- function(
 #' @export
 clear_screengrid <- function( map, layer_id = NULL) {
 	layer_id <- layerId(layer_id, "screengrid")
-	invoke_method(map, "md_layer_clear", layer_id, "screengrid" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "screengrid" )
 }
 
